@@ -6,6 +6,7 @@ from sqlalchemy.sql import func
 from sqlalchemy.dialects.mysql import TINYINT
 from marshmallow import fields
 from marshmallow import Schema
+from marshmallow import post_dump
 
 from .base import Base
 
@@ -32,6 +33,14 @@ class UserSchema(Schema):
     email = fields.String()
     password = fields.String(load_only=True)
     active = fields.Integer()
-    registration_date = fields.DateTime()
-    activation_date = fields.DateTime()
-    updated_date = fields.DateTime()
+    registration_date = fields.DateTime(data_key='registrationDate')
+    activation_date = fields.DateTime(data_key='activationDate')
+    updated_date = fields.DateTime(data_key='updatedDate')
+
+    @post_dump
+    def map_keys(self, data, **kwargs):
+        return {
+            "registrationDate": data["registration_date"],
+            "activationDate": data["activation_date"],
+            "updatedDate": data["updated_date"],
+        }
